@@ -2,8 +2,8 @@
 
 """Scaffolding exceptions module."""
 
+from collections.abc import Iterable
 from pathlib import Path
-from typing import Iterable, Iterator
 
 from pulp import LpStatus
 
