@@ -90,8 +90,8 @@ def read_contig_attributes(
     PresScoreT
         Contig's presence score
     """
-    with open(contig_attrs_path, 'r', encoding='utf-8') as cmult_fin:
-        for line in cmult_fin:
+    with open(contig_attrs_path, 'r', encoding='utf-8') as cattrs_fin:
+        for line in cattrs_fin:
             split_line = line.split()
             if split_line:
                 contig_id, mult_str, presscore_str = split_line
