@@ -82,6 +82,9 @@ MAP_OF_REGIONS_EXT = 'tsv'
 def generate_output_directory(instance_name: str) -> Path:
     """Return an unique output directory path.
 
+    The output directory name respects the following format:
+    ``<yyyy>-<mm>-<dd>_<HH>:<MM>:<SS>_<instance_name>``
+
     Parameters
     ----------
     instance_name : str
@@ -94,7 +97,7 @@ def generate_output_directory(instance_name: str) -> Path:
     """
     # DOCU output directory generated function
     return Path(
-        datetime.now().strftime('%Y-%d-%m_%H:%M:%S') + '_' + instance_name,
+        datetime.now().strftime('%Y-%m-%d_%H:%M:%S') + '_' + instance_name,
     )
 
 
@@ -106,7 +109,7 @@ def write_contigs_of_regions(
         id_container: Optional[MDCGraphIDContainer] = None):
     """Write the regions' contigs file.
 
-    # DOCU describe the output file here
+    #DOCU describe the output file here
 
     Parameters
     ----------
@@ -133,7 +136,7 @@ def write_contigs_of_regions(
 
 
 def read_contigs_of_regions(contigs_of_regions_path: Path) -> (
-        Iterator[tuple[IndexT, list[OrCT]]]):
+        Iterator[list[OrCT]]):
     """Read the regions' contigs file.
 
     Parameters
@@ -143,13 +146,11 @@ def read_contigs_of_regions(contigs_of_regions_path: Path) -> (
 
     Yields
     ------
-    IndexT
-        Index of the region
     list of OrCT
-        List of oriented contigs of the region
+        List of oriented contigs for one region
     """
     with open(contigs_of_regions_path, 'r', encoding='utf-8') as cor_in:
-        for region_ind, line in enumerate(cor_in):
+        for line in cor_in:
             orc_of_region: list[OrCT] = []
             l_orc = line.split()
             k = 0
@@ -158,7 +159,7 @@ def read_contigs_of_regions(contigs_of_regions_path: Path) -> (
                     (l_orc[k], STR_ORIENT[l_orc[k + 1]]),  # type: ignore
                 )
                 k += 2
-            yield region_ind, orc_of_region
+            yield orc_of_region
 
 
 def fmt_contigs_of_regions_filename(instance_name: str,
@@ -170,7 +171,7 @@ def fmt_contigs_of_regions_filename(instance_name: str,
     instance_name : str
         Instance name
     ilp_combination : iterable of str
-        ILP codes combination
+        ILP string code combination
 
     Returns
     -------
@@ -233,7 +234,7 @@ def fmt_map_of_regions_filename(instance_name: str,
     instance_name : str
         Instance name
     ilp_combination : iterable of str
-        ILP codes combination
+        ILP string code combination
 
     Returns
     -------
