@@ -286,7 +286,7 @@ class _ScaffoldingResultBuilder():
 
     def add_dr_region(self,
                       region_index: Optional[IndexT] = None) -> IndexT:
-        """Add a directed repeat region.
+        """Add a direct repeat region.
 
          #XXX region_index provides the first repeat
          * this works because we build pair of repeated regions
