@@ -64,6 +64,7 @@ def write_vertices_of_regions(result: ScaffoldingResult,
     vertices_of_regions_path : Path
         Path of the future file containing the regions' vertices
     """
+    # TOTEST unit test write_vertices_of_regions
     with open(vertices_of_regions_path, 'w', encoding='utf-8') as f_out:
         for region_index in range(result.number_regions()):
             line: str = ''
@@ -73,7 +74,7 @@ def write_vertices_of_regions(result: ScaffoldingResult,
 
 
 def read_vertices_of_regions(vertices_of_regions_path: Path) -> (
-        Iterator[tuple[IndexT, list[OccOrCT]]]):
+        Iterator[list[OccOrCT]]):
     """Read the regions' vertices file.
 
     Parameters
@@ -83,14 +84,11 @@ def read_vertices_of_regions(vertices_of_regions_path: Path) -> (
 
     Yields
     ------
-    IndexT
-        Index of the region
     list of OccOrCT
-        List of vertices of the region
+        List of vertices of one region
     """
-    # TOTEST function read_vertices_of_regions
     with open(vertices_of_regions_path, 'r', encoding='utf-8') as f_in:
-        for region_ind, line in enumerate(f_in):
+        for line in f_in:
             vertices_of_region: list[OccOrCT] = []
             l_occorcstr = line.split('\t')
             k = 0
@@ -102,8 +100,8 @@ def read_vertices_of_regions(vertices_of_regions_path: Path) -> (
                         IndexT(l_occorcstr[k + 2]),
                     ),
                 )
-                k += 1
-            yield region_ind, vertices_of_region
+                k += 3
+            yield vertices_of_region
 
 
 def fmt_vertices_of_regions_filename(instance_name: str,
@@ -115,13 +113,14 @@ def fmt_vertices_of_regions_filename(instance_name: str,
     instance_name : str
         Instance name
     ilp_combination : iterable of str
-        ILP codes combination
+        ILP string code combination
 
     Returns
     -------
     str
         Formatted file name
     """
+    # TOTEST unit test fmt_vertices_of_regions_filename
     return (
         f'{VERTICES_OF_REGIONS_PREFIX}_{instance_name}'
         f"_{'_'.join(ilp_combination)}"
@@ -154,7 +153,7 @@ def write_found_repeated_fragments(var: Union[PuLPVarInvF, PuLPVarDirF],
     repeated_fragments_path : Path
         Path of the future file containing the repeated fragments solution
     """
-    # TOTEST write repeated fragments debug function
+    # TOTEST unit test write_found_repeated_fragments
     with open(repeated_fragments_path, 'w', encoding='utf-8') as f_out:
         if isinstance(var, PuLPVarInvF):
             for (v_ind, v_or, v_occ), _ in var.invf_solution():
@@ -186,7 +185,7 @@ def read_found_repeated_fragments(
     OccOrCT
         Repeat fragments canonical
     """
-    # TOTEST read repeated fragments debug function
+    # TOTEST unit test read_found_repeated_fragments
     with open(repeated_fragments_path, 'r', encoding='utf-8') as f_in:
         for line in f_in:
             code_canonical = line.split()
@@ -207,13 +206,14 @@ def fmt_found_repeated_fragments_filename(
     instance_name : str
         Instance name
     ilp_combination : iterable of str
-        ILP codes combination
+        ILP string code combination
 
     Returns
     -------
     str
         Formatted file name
     """
+    # TOTEST unit test fmt_found_repeated_fragments_filename
     return (
         f'{FOUND_REPFRAG_PREFIX}_{instance_name}'
         f"_{'_'.join(ilp_combination)}"
