@@ -4,13 +4,21 @@
 
 # pylint: disable=compare-to-zero, missing-raises-doc
 from pathlib import Path
-from typing import Iterator
 
 from revsymg.graphs import RevSymGraph
-from revsymg.index_lib import FORWARD_INT, REVERSE_INT, IndexT, IndOrT
+from revsymg.index_lib import FORWARD_INT, REVERSE_INT, IndOrT
 
-from khloraascaf.assembly_graph import AssemblyGraph, OrCT, rev_oriented_contig
-from khloraascaf.inputs import STR_ORIENT
+from khloraascaf.assembly_graph import (
+    AssemblyGraph,
+    OrCT,
+    fmt_oriented_contig_paths_filename,
+    fmt_region_paths_filename,
+    read_oriented_contig_paths,
+    read_region_paths,
+    rev_oriented_contig,
+    write_oriented_contig_paths,
+    write_region_paths,
+)
 
 
 # ============================================================================ #
@@ -39,6 +47,14 @@ _DR_UN_REG_PATHS = _DR_UN_DIR / 'region_paths.tsv'
 _DR_UN_ORC_PATHS = _DR_UN_DIR / 'oriented_contig_paths.tsv'
 
 
+# ---------------------------------------------------------------------------- #
+#                                      UN                                      #
+# ---------------------------------------------------------------------------- #
+_UN_DIR = _TOY_DATADIR / 'un'
+_UN_SOL_REGMAP = _UN_DIR / 'map_of_regions_sol.tsv'
+_UN_SOL_REGCTG = _UN_DIR / 'contigs_of_regions_sol.tsv'
+
+
 # ============================================================================ #
 #                                TEST FUNCTIONS                                #
 # ============================================================================ #
@@ -53,8 +69,18 @@ def test_all_region_paths_ir_un():
         _IR_UN_SOL_REGCTG_F,
     )
     s_region_paths: set[tuple[IndOrT, ...]] = {
-        tuple(region_path)
-        for region_path in read_region_paths(_IR_UN_REG_PATHS)
+        (
+            (0, FORWARD_INT),
+            (1, FORWARD_INT),
+            (2, FORWARD_INT),
+            (1, REVERSE_INT),
+        ),
+        (
+            (0, FORWARD_INT),
+            (1, FORWARD_INT),
+            (2, REVERSE_INT),
+            (1, REVERSE_INT),
+        ),
     }
     asm_graph_paths = [tuple(l) for l in asm_graph.all_region_paths()]
     assert len(asm_graph_paths) == len(s_region_paths)
@@ -70,8 +96,31 @@ def test_all_region_paths_dr_un():
         _DR_UN_SOL_REGCTG,
     )
     s_region_paths: set[tuple[IndOrT, ...]] = {
-        tuple(region_path)
-        for region_path in read_region_paths(_DR_UN_REG_PATHS)
+        (
+            (0, FORWARD_INT),
+            (1, FORWARD_INT),
+            (2, FORWARD_INT),
+            (1, FORWARD_INT),
+        ),
+    }
+    asm_graph_paths = [tuple(l) for l in asm_graph.all_region_paths()]
+    assert len(asm_graph_paths) == len(s_region_paths)
+    for reg_path in asm_graph_paths:
+        assert reg_path in s_region_paths
+
+
+# TOTEST test_all_regions_paths_un
+def test_all_region_paths_un():
+    """Test all_region_paths method for UN."""
+    # TOTEST use fixture for assembly graph
+    asm_graph = AssemblyGraph(
+        _UN_SOL_REGMAP,
+        _UN_SOL_REGCTG,
+    )
+    s_region_paths: set[tuple[IndOrT, ...]] = {
+        (
+            (0, FORWARD_INT),
+        ),
     }
     asm_graph_paths = [tuple(l) for l in asm_graph.all_region_paths()]
     assert len(asm_graph_paths) == len(s_region_paths)
@@ -90,8 +139,24 @@ def test_all_oriented_contig_paths_ir_un():
         _IR_UN_SOL_REGCTG_F,
     )
     s_orc_paths: set[tuple[OrCT, ...]] = {
-        tuple(orc_path)
-        for orc_path in read_oriented_contig_paths(_IR_UN_ORC_PATHS)
+        (
+            ('C0', FORWARD_INT),
+            ('C1', REVERSE_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+            ('C4', REVERSE_INT),
+            ('C3', REVERSE_INT),
+            ('C2', FORWARD_INT),
+        ),
+        (
+            ('C0', FORWARD_INT),
+            ('C1', REVERSE_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+            ('C4', FORWARD_INT),
+            ('C3', REVERSE_INT),
+            ('C2', FORWARD_INT),
+        ),
     }
     asm_graph_paths = [tuple(l) for l in asm_graph.all_oriented_contig_paths()]
     assert len(asm_graph_paths) == len(s_orc_paths)
@@ -107,8 +172,15 @@ def test_all_oriented_contig_paths_dr():
         _DR_UN_SOL_REGCTG,
     )
     s_orc_paths: set[tuple[OrCT, ...]] = {
-        tuple(orc_path)
-        for orc_path in read_oriented_contig_paths(_DR_UN_ORC_PATHS)
+        (
+            ('C0', FORWARD_INT),
+            ('C1', REVERSE_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+            ('C4', FORWARD_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+        ),
     }
     asm_graph_paths = [tuple(l) for l in asm_graph.all_oriented_contig_paths()]
     assert len(asm_graph_paths) == len(s_orc_paths)
@@ -165,65 +237,123 @@ def test_rev_oriented_contig():
     assert rev_oriented_contig(('3', REVERSE_INT)) == ('3', FORWARD_INT)
 
 
-# ============================================================================ #
-#                                   FUNCTIONS                                  #
-# ============================================================================ #
-def read_region_paths(region_paths_file: Path) -> Iterator[list[IndOrT]]:
-    """Read region paths from file.
-
-    Parameters
-    ----------
-    region_paths_file : Path
-        Region paths file path
-
-    Yields
-    ------
-    list of IndOrT
-        Region path
-    """
-    # REFACTOR API function?
-    with open(region_paths_file, 'r', encoding='utf-8') as regpaths_in:
-        for line in regpaths_in:
-            region_path = []
-            l_regindor = line.split()
-            k = 0
-            while k < len(l_regindor) - 1:
-                region_path.append(
-                    (
-                        IndexT(l_regindor[k]),
-                        STR_ORIENT[l_regindor[k + 1]],  # type: ignore
-                    ),
-                )
-                k += 2
-            yield region_path
+# ---------------------------------------------------------------------------- #
+#                              Write_region_paths                              #
+# ---------------------------------------------------------------------------- #
+def test_write_region_paths():
+    """Test write_region_paths function."""
+    asm_graph = AssemblyGraph(
+        _IR_UN_SOL_REGMAP,
+        _IR_UN_SOL_REGCTG_F,
+    )
+    region_paths_file = Path('tmp_region_paths.tsv')
+    write_region_paths(asm_graph.all_region_paths(), region_paths_file)
+    with open(region_paths_file, 'r', encoding='utf-8') as f_in:
+        to_test_lines: set[tuple[str, ...]] = {
+            tuple(line.split()) for line in f_in
+        }
+    with open(_IR_UN_REG_PATHS, 'r', encoding='utf-8') as f_in:
+        sol_lines: set[tuple[str, ...]] = {
+            tuple(line.split()) for line in f_in
+        }
+    assert to_test_lines == sol_lines
+    region_paths_file.unlink()
 
 
-def read_oriented_contig_paths(oriented_contig_paths_file: Path) -> (
-        Iterator[list[OrCT]]):
-    """Read region paths from file.
+# ---------------------------------------------------------------------------- #
+#                               Read_region_paths                              #
+# ---------------------------------------------------------------------------- #
+def test_read_region_paths():
+    """Test read_region_paths function."""
+    region_paths = read_region_paths(_IR_UN_REG_PATHS)
+    s_region_paths: set[tuple[IndOrT, ...]] = {
+        (
+            (0, FORWARD_INT),
+            (1, FORWARD_INT),
+            (2, FORWARD_INT),
+            (1, REVERSE_INT),
+        ),
+        (
+            (0, FORWARD_INT),
+            (1, FORWARD_INT),
+            (2, REVERSE_INT),
+            (1, REVERSE_INT),
+        ),
+    }
+    for region_path in region_paths:
+        assert tuple(region_path) in s_region_paths
 
-    Parameters
-    ----------
-    oriented_contig_paths_file : Path
-        Region paths file path
 
-    Yields
-    ------
-    list of OrCT
-        Oriented contig path
-    """
-    # REFACTOR API function?
-    with open(oriented_contig_paths_file, 'r', encoding='utf-8') as regpaths_in:
-        for line in regpaths_in:
-            oriented_contig_path = []
-            l_orc = line.split()
-            k = 0
-            while k < len(l_orc) - 1:
-                oriented_contig_path.append(
-                    (
-                        l_orc[k],
-                        STR_ORIENT[l_orc[k + 1]],  # type: ignore
-                    ),
-                )
-                k += 2
-            yield oriented_contig_path
+# ---------------------------------------------------------------------------- #
+#                           Fmt_region_paths_filename                          #
+# ---------------------------------------------------------------------------- #
+def test_fmt_region_paths_file():
+    """Test fmt_region_paths_filename."""
+    assert fmt_region_paths_filename('jaaj', ('ir', 'un')) == (
+        'region_paths_jaaj_ir_un.tsv'
+    )
+
+
+# ---------------------------------------------------------------------------- #
+#                          Write_oriented_contig_paths                         #
+# ---------------------------------------------------------------------------- #
+def test_write_oriented_contig_paths():
+    """Test write_oriented_contig_paths function."""
+    asm_graph = AssemblyGraph(
+        _IR_UN_SOL_REGMAP,
+        _IR_UN_SOL_REGCTG_F,
+    )
+    oriented_contig_paths_file = Path('tmp_oriented_contig_paths.tsv')
+    write_oriented_contig_paths(
+        asm_graph.all_oriented_contig_paths(),
+        oriented_contig_paths_file)
+    with open(oriented_contig_paths_file, 'r', encoding='utf-8') as f_in:
+        to_test_lines: set[tuple[str, ...]] = {
+            tuple(line.split()) for line in f_in
+        }
+    with open(_IR_UN_ORC_PATHS, 'r', encoding='utf-8') as f_in:
+        sol_lines: set[tuple[str, ...]] = {
+            tuple(line.split()) for line in f_in
+        }
+    assert to_test_lines == sol_lines
+    oriented_contig_paths_file.unlink()
+
+
+# ---------------------------------------------------------------------------- #
+#                          Read_oriented_contig_paths                          #
+# ---------------------------------------------------------------------------- #
+def test_read_oriented_contig_paths():
+    """Test read_oriented_contig_paths function."""
+    oriented_contig_paths = read_oriented_contig_paths(_IR_UN_ORC_PATHS)
+    s_oriented_contig_paths: set[tuple[OrCT, ...]] = {
+        (
+            ('C0', FORWARD_INT),
+            ('C1', REVERSE_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+            ('C4', REVERSE_INT),
+            ('C3', REVERSE_INT),
+            ('C2', FORWARD_INT),
+        ),
+        (
+            ('C0', FORWARD_INT),
+            ('C1', REVERSE_INT),
+            ('C2', REVERSE_INT),
+            ('C3', FORWARD_INT),
+            ('C4', FORWARD_INT),
+            ('C3', REVERSE_INT),
+            ('C2', FORWARD_INT),
+        ),
+    }
+    for oriented_contig_path in oriented_contig_paths:
+        assert tuple(oriented_contig_path) in s_oriented_contig_paths
+
+
+# ---------------------------------------------------------------------------- #
+#                      Fmt_oriented_contig_paths_filename                      #
+# ---------------------------------------------------------------------------- #
+def test_fmt_oriented_contig_paths_file():
+    """Test fmt_oriented_contig_paths_filename."""
+    assert fmt_oriented_contig_paths_filename('jaaj', ('ir', 'un')) == (
+        'oriented_contig_paths_jaaj_ir_un.tsv'
+    )
